/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.field.model;

import java.beans.PropertyChangeListener;
import java.io.IOException;
import java.util.List;
import nl.cloudfarming.client.model.EntityManager;
import org.netbeans.api.project.Project;

/**
 *
 * @author Timon Veenstra
 */
public interface FieldManager extends EntityManager<Field> {

    public static final String PROP_PROGRESS = "progress";
    public static final String PROP_FINISH = "finish";

    /**
     * Load a CropField from a file object
     *
     * @param fileObject
     * @return the loaded object
     */
//    Field loadField(FileObject fileObject);

    /**
     * Save an object to the specified file object For fields use {@link FieldManager#save(nl.cloudfarming.client.field.model.Field, org.netbeans.api.project.Project)
     * }
     *
     * @see {@link FieldManager#save(nl.cloudfarming.client.field.model.Field, org.netbeans.api.project.Project)
     * }
     * @param object the object to save
     * @param fileObject
     */
//    void save(Object object, FileObject fileObject);

    /**
     * Save a field in the context of a project.
     *
     * @param field
     * @param project
     */
//    public FileObject save(Field field, Project project);

    /**
     * Import the supplied shapes into the context of the provided project. This
     * method is ui blocking and shoulld NOT be called from the AWT!
     *
     * @param shapes
     * @param project
     * @param progressListener which will be notified on any progress by the
     * progress event key. newValue will contain 100 *
     * (shapes.size()/processedShapes)
     * @return list of created fields
     */
    public List<Field> importTreatmentZones(List<Shape> shapes, Project project, String fieldName, PropertyChangeListener progressListener);

    /**
     * {@link FieldManager#importTreatmentZones(java.util.List, org.netbeans.api.project.Project, java.lang.String, java.beans.PropertyChangeListener)
     * }
     *
     * @param shapes
     * @param project
     * @param progressListener
     * @return
     */
    public List<Field> importFields(List<Shape> shapes, Project project, PropertyChangeListener progressListener);

    /**
     * Import a shape into a field object
     *
     * @param shape
     * @param project
     */
    public Field importField(Shape shape, Project project) throws IOException;

    /**
     * Import a shape into a treatmentzone object relative to a field
     *
     * @param shape
     * @param project
     * @param field field the treatmentzone should be imported to
     * @param groupName name of the treatmentzone group
     * @return field field with the added treatmentzone
     * @throws IOException
     */
    public Field importTreatmentZone(Shape shape, Project project, Field field, String groupName) throws IOException;

    /**
     * Read and return all fields from this projects dir
     *
     * @return List of fields
     */
    public List<Field> getFields(Project project);
}
